Is this THE equation for parabolic fix ?

Hello There, Guest! Login Register

Login
Username: |
Password: | Lost Password?
| Remember me

Threaded Mode Is this THE equation for parabolic fix ?
tommy1729 Ultimate Fellow Posts: 1,742 Threads: 382 Joined: Feb 2009 #1 03/18/2015, 09:49 PM Since jan 2015 I am very intrested in parabolic fixpoints again. I take the fixpoint at 0 for simplicity. Maybe I havent read the right books, but I feel a large gap in understanding of the subject. On the other hand - as usual - I was not able to find the answers anywhere. Anyway I came to the idea of working with analogue ideas of the hyperbolic fixpoint methods. First I used the limit ideas. This lead to the results here : http://math.eretrandre.org/tetrationforu...hp?tid=951 But I do not want just limits now , I want equations and series expansions. The problem with Taylor is that it has zero radius of convergeance. I considered the so-called Tommy-Kouznetsov expansions and the tommy equation and so forth. But they do not seem to work either. So apart from the limit formula's - and their explaination - and some perturbations I know almost nothing for sure. Since trying to find the "right equation" AND the right (associated) converging expansions (as I tried in the thread tommy equation) might be hard because we want 2 things at the same time , I consider to return to Taylor series and just find the "right equation". ( It seems easier to find the right equation , then it is to find the right expansion WITHOUT the equation , since the last does not seem to make sense ) SO we return to the Taylor series with nonzero radius. SO what is THE equation for parabolic fixpoints ? For hyperbolic it turned out to be g( f(x) ) = f(A x) Notice that near the fixpoint 0 the function g behaves like A x and the iterates behave like A^x. Notice A^x is the super of A x. The analogue should then be g ( f(x) ) = f( q(A,x) ) Now there are 2 ideas about what q should be based on the above. ( and those 2 might be both correct and equivalent ! ) 1) q(A,x) is the Ath iteration of a nonlinear polynomial truncation of g(x). We then solve the equation by using the Taylor expansion of q(A,x). 2) For simplicity assume g grows to 0 at a rate 1/sqrt(x). ( yes this idea resembles http://math.eretrandre.org/tetrationforu...hp?tid=951 ) To compute what t(x) = 1/sqrt(x) is the super of we use the traditional : t(x) is super of t( t^[-1](x) + 1). so here 1/sqrt(x) is the super of 1/sqrt(1/x^2 + 1)) = x/sqrt(x^2 + 1). Now let K(x) be the Taylor of x/sqrt(x^2 + 1). Then we get the equation g( f(x) ) = f( K(x) ) In both cases [ 1) and 2) ] it is assumed that g can be solved in terms of a Taylor series with nonzero radius. ( I estimate the radius between 0.5 and 1. ) From this we can then compute the analytic superfunctions. I noticed that this probably has an analogue in terms of linear algebra ; G( F(x) ) = F ( T(x) ) is isomorphic to G * F = F * T where G,F,T are carleman matrices. Im skeptical about what I wrote , so I wonder what you guys think about it. If the parabolic indeed works similar to the hyperbolic case I find that an intresting " meta-math result " ; by which I mean an intresting fundamental generalization. regards tommy1729 " Truth is whatever does not go away when we stop believing in it " tommy1729 Website Find Reply sheldonison Long Time Fellow Posts: 684 Threads: 24 Joined: Oct 2008 #2 03/19/2015, 10:22 AM (This post was last modified: 03/20/2015, 11:45 AM by sheldonison.) (03/18/2015, 09:49 PM)tommy1729 Wrote: Since jan 2015 I am very intrested in parabolic fixpoints again. I take the fixpoint at 0 for simplicity. Maybe I havent read the right books, but I feel a large gap in understanding of the subject. Here is the asymptotic series for the Abel function for the parabolic case; for example for We have My understanding is that the series is asymptotic because there are actually two different superfunctions and Abel functions, depending on whether you are working with the repelling sector, for z>0, or the attracting sector, for z<0. From a practical point of view, for one can iterate a few times or for one can iterate a few times, before calculating , so that z is closer to zero. Then the series convergence is remarkably good, allowing results of arbitrarily high precision without any difficulties. Also, for the Abel function we can add any arbitrary additive constant to . For it is customary to use , or equivalently to replace the term with . Again, this is because there are really two completely different superfunctions for f(z), with different Abel functions, that have the same series expansions. - Sheldon Find Reply tommy1729 Ultimate Fellow Posts: 1,742 Threads: 382 Joined: Feb 2009 #3 03/19/2015, 02:31 PM (This post was last modified: 03/19/2015, 02:34 PM by tommy1729.) (03/19/2015, 10:22 AM)sheldonison Wrote: (03/18/2015, 09:49 PM)tommy1729 Wrote: Since jan 2015 I am very intrested in parabolic fixpoints again. I take the fixpoint at 0 for simplicity. Maybe I havent read the right books, but I feel a large gap in understanding of the subject. Here is the asymptotic series for the Abel function for the parabolic case; for example for We have My understanding is that the series is asymptotic because there are actually two different superfunctions and Abel functions, depending on whether you are working with the repelling sector, for z>0, or the attracting sector, for z<0. From a practical point of view, for one can iterate a few times or for one can iterate a few times, before calculating , so that z is closer to zero. Then the series convergence is remarkably good, allowing results of arbitrarily high precision without any difficulties. Also, for the Abel function we can add any arbitrary additive constant to . For it is customary to use , or equivalently to replace the term with . Again, this is because there are really two completely different superfunctions for f(z), with different Abel functions, that have the same series expansions. What you have is not a Taylor series, so how did you find this expansion. Also this does not answer the op. I know ways to get the Abel , but i forgot why getting to z=0 helps. Probably perturbation theory. Btw for x + x^N the situation is different for Every N. Lots to do. Regards Tommy1729 Website Find Reply sheldonison Long Time Fellow Posts: 684 Threads: 24 Joined: Oct 2008 #4 03/19/2015, 09:24 PM (This post was last modified: 03/19/2015, 09:34 PM by sheldonison.) (03/19/2015, 02:31 PM)tommy1729 Wrote: What you have is not a Taylor series, so how did you find this expansion. This series uses Jean Ecalle's FPS solution; there are many other posts on mathoverflow by Will Jagy and Henryk Trapman and Gottried Helms, about Jean Ecalle's parabolic solution. (03/19/2015, 02:31 PM)tommy1729 Wrote: Also this does not answer the op. I know ways to get the Abel , but i forgot why getting to z=0 helps. Probably perturbation theory. It sounds like you're looking for the inverse of the parabolic solution for the Abel function, also developed around the fixed point, no? I haven't seen such an "inverse Abel function" formal power series; so it might be novel. The form might be similar to what was posted by Mick, on mathstack, but it would require a 1/x term to be the inverse of Ecalle's solution. Also, such an FPS would also likely have a zero radius of convergence for the same reasons that Ecalle's solution is an asymptotic series; which I briefly explained. (03/19/2015, 02:31 PM)tommy1729 Wrote: Btw for x + x^N the situation is different for Every N. True; Will Jagy explains the general case in some of his posts. I just figured I would give the FPS series for iterating the parabolic case; , to help you out. Scaling this FPS solution gives the solution for iterating which you mentioned earlier. Abel function for in terms of the Abel function for derived using - Sheldon Find Reply tommy1729 Ultimate Fellow Posts: 1,742 Threads: 382 Joined: Feb 2009 #5 03/19/2015, 11:37 PM (03/19/2015, 09:24 PM)sheldonison Wrote: (03/19/2015, 02:31 PM)tommy1729 Wrote: What you have is not a Taylor series, so how did you find this expansion. This series uses Jean Ecalle's FPS solution; there are many other posts on mathoverflow by Will Jagy and Henryk Trapman and Gottried Helms, about Jean Ecalle's parabolic solution. (03/19/2015, 02:31 PM)tommy1729 Wrote: Also this does not answer the op. I know ways to get the Abel , but i forgot why getting to z=0 helps. Probably perturbation theory. It sounds like you're looking for the inverse of the parabolic solution for the Abel function, also developed around the fixed point, no? I haven't seen such an "inverse Abel function" formal power series; so it might be novel. The form might be similar to what was posted by Mick, on mathstack, but it would require a 1/x term to be the inverse of Ecalle's solution. Also, such an FPS would also likely have a zero radius of convergence for the same reasons that Ecalle's solution is an asymptotic series; which I briefly explained. (03/19/2015, 02:31 PM)tommy1729 Wrote: Btw for x + x^N the situation is different for Every N. True; Will Jagy explains the general case in some of his posts. I just figured I would give the FPS series for iterating the parabolic case; , to help you out. Scaling this FPS solution gives the solution for iterating which you mentioned earlier. Abel function for in terms of the Abel function for derived using What Will Jagy posted or what you call the ecalle FPS method ( what is FPS ? ) , I call the Julia method. It is now clear again to me why getting closer to z=0 works ; the limit form and Taylor are equivalent (isomorphic). I feel a bit dumb for forgetting it. I wanted to post something about matrices but in your link it seems Gottfried already found that. I wonder if these methods for parabolic generalize easy into methods/expansions that work for both parabolic and hyperbolic. Thanks for the refreshing link. I will start a new thread for a question that I think is related. Also Im working on an idea that could be informally described as " fake parabolic function theory " , but that is for much later. Although the amount of questions unanswered remains about the same , Im starting to feel a generalization... a deep connection between concepts. But I have to start a new thread because otherwise Im going a bit offtopic with respect to the OP here. Maybe we need a Julia-like equation for the inverse Abel to answer most questions ? regards tommy1729 " Proof implies both truth and why " tommy1729 Website Find Reply tommy1729 Ultimate Fellow Posts: 1,742 Threads: 382 Joined: Feb 2009 #6 04/16/2015, 10:01 PM (03/19/2015, 09:24 PM)sheldonison Wrote: (03/19/2015, 02:31 PM)tommy1729 Wrote: What you have is not a Taylor series, so how did you find this expansion. This series uses Jean Ecalle's FPS solution; there are many other posts on mathoverflow by Will Jagy and Henryk Trapman and Gottried Helms, about Jean Ecalle's parabolic solution. (03/19/2015, 02:31 PM)tommy1729 Wrote: Also this does not answer the op. I know ways to get the Abel , but i forgot why getting to z=0 helps. Probably perturbation theory. It sounds like you're looking for the inverse of the parabolic solution for the Abel function, also developed around the fixed point, no? I haven't seen such an "inverse Abel function" formal power series; so it might be novel. The form might be similar to what was posted by Mick, on mathstack, but it would require a 1/x term to be the inverse of Ecalle's solution. Also, such an FPS would also likely have a zero radius of convergence for the same reasons that Ecalle's solution is an asymptotic series; which I briefly explained. (03/19/2015, 02:31 PM)tommy1729 Wrote: Btw for x + x^N the situation is different for Every N. True; Will Jagy explains the general case in some of his posts. I just figured I would give the FPS series for iterating the parabolic case; , to help you out. Scaling this FPS solution gives the solution for iterating which you mentioned earlier. Abel function for in terms of the Abel function for derived using About that novel for the inverse Abel , A) replace in the FPS method ln with its Fps and also x^-n with its fps. Now we have a Taylor series. B) use series reversion C) you have the formal powerseries for the inverse Abel. What do you think ? This may have apps to other ideas ( continuum product etc ) Regards Tommy1729 Website Find Reply
« Next Oldest | Next Newest »

Possibly Related Threads…
Thread | Author | Replies | Views | Last Post
| tommy's displacement equation | tommy1729 | 1 | 306 | 09/16/2022, 12:24 PM Last Post: tommy1729
| Parabolic Formal Powerseries | bo198214 | 7 | 771 | 09/11/2022, 11:36 AM Last Post: bo198214
| Borel summation, Mellin Transforms, Parabolic iteration | JmsNxn | 5 | 680 | 09/10/2022, 03:12 PM Last Post: bo198214
| A special equation : f^[t](x) = f(t x)/t | tommy1729 | 6 | 919 | 06/17/2022, 12:16 PM Last Post: tommy1729
| [MSE] Help on a special kind of functional equation. | MphLee | 4 | 2,143 | 06/14/2021, 09:52 PM Last Post: JmsNxn
| Logical tetration equation | Xorter | 0 | 3,561 | 02/01/2018, 10:29 PM Last Post: Xorter
| Some sort equation ... | tommy1729 | 0 | 3,531 | 10/15/2015, 12:12 PM Last Post: tommy1729
| An intresting equation ? Taking squares by equation. | tommy1729 | 0 | 3,647 | 05/08/2015, 11:37 PM Last Post: tommy1729
| Conservation of functional equation ? | tommy1729 | 0 | 3,628 | 05/01/2015, 10:03 PM Last Post: tommy1729
| Mick's differential equation | tommy1729 | 3 | 7,425 | 04/10/2015, 04:14 PM Last Post: tommy1729

- View a Printable Version

Users browsing this thread: 1 Guest(s)